module.exports = defineTest({
	description: 'detect side-effects in overwritten properties of object literals'
});
